==> connectagram_1.1.2.orig.tar.bz2: connectagram-1.1.2/translations/connectagram_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>ChainPattern</name>
    <message>
        <location filename="../src/pattern.h" line="143"/>
        <source>Chain</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <location filename="../src/clock.cpp" line="70"/>
        <source>Loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="112"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <location filename="../src/definitions.cpp" line="36"/>
        <source>Definitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/definitions.cpp" line="145"/>
        <source>Downloading definition...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/definitions.cpp" line="153"/>
        <source>Unsolved word</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <location filename="../src/dictionary.cpp" line="148"/>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dictionary.cpp" line="155"/>
        <source>No definition found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dictionary.cpp" line="158"/>
        <source>Unable to connect to Wiktionary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <location filename="../src/pattern.h" line="168"/>
        <source>Fence</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="184"/>
        <source>Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="184"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="45"/>
        <source>New Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="58"/>
        <location filename="../src/window.cpp" line="266"/>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="58"/>
        <location filename="../src/window.cpp" line="267"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="58"/>
        <location filename="../src/window.cpp" line="268"/>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="58"/>
        <location filename="../src/window.cpp" line="269"/>
        <source>Very High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="93"/>
        <location filename="../src/window.cpp" line="280"/>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="95"/>
        <location filename="../src/window.cpp" line="282"/>
        <source>Word Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="94"/>
        <location filename="../src/window.cpp" line="281"/>
        <source>Amount of Words:</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/new_game_dialog.cpp" line="143"/>
        <location filename="../src/window.cpp" line="282"/>
        <source>%n letter(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <location filename="../src/pattern.h" line="193"/>
        <source>Rings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <location filename="../src/score_board.cpp" line="31"/>
        <source>Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="35"/>
        <source>Score</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="35"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="35"/>
        <source>Words</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="35"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <location filename="../src/pattern.h" line="214"/>
        <source>Stairs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <location filename="../src/pattern.h" line="231"/>
        <source>Twisty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <location filename="../src/pattern.h" line="254"/>
        <source>Wave</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="69"/>
        <location filename="../src/window.cpp" line="84"/>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="96"/>
        <source>Loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="96"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="119"/>
        <source>Definitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="125"/>
        <source>Hint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="156"/>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="157"/>
        <source>&amp;New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="157"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="158"/>
        <source>&amp;Choose...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="167"/>
        <source>&amp;Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="160"/>
        <location filename="../src/window.cpp" line="326"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="160"/>
        <source>P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="162"/>
        <source>&amp;Hint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="162"/>
        <source>H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <source>D&amp;efinitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <source>D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="168"/>
        <source>&amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="170"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="170"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="172"/>
        <source>&amp;Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <source>Application &amp;Language...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="175"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="176"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="177"/>
        <source>About &amp;Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="205"/>
        <source>Choose Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="205"/>
        <location filename="../src/window.cpp" line="283"/>
        <source>Game Number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="209"/>
        <source>Sorry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="209"/>
        <source>Unable to start requested game.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="249"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="250"/>
        <source>Connectagram</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="251"/>
        <source>A word unscrambling game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="252"/>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="253"/>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="254"/>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="277"/>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="279"/>
        <source>Pattern:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="326"/>
        <source>&amp;Resume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> connectagram_1.2.1.orig.tar.bz2: connectagram-1.2.1/translations/connectagram_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>ChainPattern</name>
    <message>
        <location filename="../src/pattern.h" line="145"/>
        <source>Chain</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <location filename="../src/clock.cpp" line="70"/>
        <source>Loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="112"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <location filename="../src/definitions.cpp" line="36"/>
        <source>Definitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/definitions.cpp" line="145"/>
        <source>Downloading definition...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/definitions.cpp" line="153"/>
        <source>Unsolved word</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <location filename="../src/dictionary.cpp" line="133"/>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dictionary.cpp" line="140"/>
        <source>No definition found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dictionary.cpp" line="143"/>
        <source>Unable to connect to Wiktionary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <location filename="../src/pattern.h" line="170"/>
        <source>Fence</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="173"/>
        <source>Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="173"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="44"/>
        <source>New Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="57"/>
        <location filename="../src/window.cpp" line="278"/>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="57"/>
        <location filename="../src/window.cpp" line="279"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="57"/>
        <location filename="../src/window.cpp" line="280"/>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="57"/>
        <location filename="../src/window.cpp" line="281"/>
        <source>Very High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="92"/>
        <location filename="../src/window.cpp" line="292"/>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="94"/>
        <location filename="../src/window.cpp" line="294"/>
        <source>Word Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="93"/>
        <location filename="../src/window.cpp" line="293"/>
        <source>Amount of Words:</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/new_game_dialog.cpp" line="142"/>
        <location filename="../src/window.cpp" line="294"/>
        <source>%n letter(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <location filename="../src/pattern.h" line="195"/>
        <source>Rings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <location filename="../src/score_board.cpp" line="33"/>
        <source>Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Score</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Words</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <location filename="../src/pattern.h" line="216"/>
        <source>Stairs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <location filename="../src/pattern.h" line="233"/>
        <source>Twisty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <location filename="../src/pattern.h" line="256"/>
        <source>Wave</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="70"/>
        <location filename="../src/window.cpp" line="85"/>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="97"/>
        <source>Loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="97"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="122"/>
        <source>Definitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="128"/>
        <source>Hint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="159"/>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="160"/>
        <source>&amp;New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="161"/>
        <source>&amp;Choose...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="170"/>
        <source>&amp;Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="163"/>
        <location filename="../src/window.cpp" line="338"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="163"/>
        <source>P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <source>&amp;Hint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <source>H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="168"/>
        <source>D&amp;efinitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="168"/>
        <source>D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>&amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="176"/>
        <source>&amp;Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="177"/>
        <source>Application &amp;Language...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="179"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="180"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="182"/>
        <source>About &amp;Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="217"/>
        <source>Choose Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="217"/>
        <location filename="../src/window.cpp" line="295"/>
        <source>Game Number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="221"/>
        <source>Sorry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="221"/>
        <source>Unable to start requested game.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="261"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="30"/>
        <location filename="../src/window.cpp" line="262"/>
        <source>Connectagram</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="263"/>
        <source>A word unscrambling game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="264"/>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="265"/>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="266"/>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="289"/>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="291"/>
        <source>Pattern:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="338"/>
        <source>&amp;Resume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
